@@ -28,8 +28,8 @@ ql_business_day = {
     "No Adjustment": ql.Unadjusted, 
     "Following": ql.Following, 
     "Modified Following": ql.ModifiedFollowing,
-    "Preceeding": ql.Preceding, 
-    "Modified Preceeding": ql.ModifiedPreceding
+    "Preceding": ql.Preceding, 
+    "Modified Preceding": ql.ModifiedPreceding
 }
 
 ql_date_generation = {
