@@ -4,12 +4,18 @@ from .ql_conventions import *
 import QuantLib as ql
 
 
-def create_calendar(description: str, holidays:List[Holiday] = []):
+def create_calendar(description: str, holidays:List[Holiday] = [], mycal = None):
+
     cal = ql.BespokeCalendar(description)
     qldates = [datestr_to_qldate(holiday.date) for holiday in holidays]
     for qldate in qldates:
         cal.addHoliday(qldate)
-    calendar = ql.JointCalendar(cal, ql.WeekendsOnly())
+    
+    if not mycal:
+        calendar = ql.JointCalendar(cal, ql.WeekendsOnly())
+    else:
+        calendar = ql.JointCalendar(cal, mycal)
+    
     return calendar
     
 
